FleetClient

Struct FleetClient 

pub struct FleetClient { /* private fields */ }
A client for interacting with the Burn Central Fleet API.

Implementations

Source

impl FleetClient

pub fn new(env: Env) -> Self

Create a new FleetClient for the given environment.

pub fn from_url(url: Url) -> Self

Create a FleetClient with a custom base URL.

pub fn register( &self, registration_token: impl Into<String>, identity_key: impl Into<String>, metadata: Option<Value>, ) -> Result<FleetDeviceAuthTokenResponse, ClientError>

Register the device and exchange credentials for a JWT.

pub fn sync( &self, token: impl AsRef<str>, metadata: Option<Value>, ) -> Result<FleetSyncSnapshotResponse, ClientError>

Sync device state with the fleet.

pub fn model_download( &self, auth_token: impl AsRef<str>, ) -> Result<FleetModelDownloadResponse, ClientError>

Get the model download information for the device’s assigned fleet.

pub fn ingest_telemetry( &self, auth_token: impl AsRef<str>, events: TelemetryIngestionEvents, ) -> Result<(), ClientError>

Ingest telemetry events for a fleet device.