pub struct FleetClient { /* private fields */ }Expand description
A client for interacting with the Burn Central Fleet API.
Implementations
Sourceimpl FleetClient
impl FleetClient
Sourcepub fn register(
&self,
registration_token: impl Into<String>,
identity_key: impl Into<String>,
metadata: Option<Value>,
) -> Result<FleetDeviceAuthTokenResponse, ClientError>
pub fn register( &self, registration_token: impl Into<String>, identity_key: impl Into<String>, metadata: Option<Value>, ) -> Result<FleetDeviceAuthTokenResponse, ClientError>
Register the device and exchange credentials for a JWT.
Sourcepub fn sync(
&self,
token: impl AsRef<str>,
metadata: Option<Value>,
) -> Result<FleetSyncSnapshotResponse, ClientError>
pub fn sync( &self, token: impl AsRef<str>, metadata: Option<Value>, ) -> Result<FleetSyncSnapshotResponse, ClientError>
Sync device state with the fleet.
Sourcepub fn model_download(
&self,
auth_token: impl AsRef<str>,
) -> Result<FleetModelDownloadResponse, ClientError>
pub fn model_download( &self, auth_token: impl AsRef<str>, ) -> Result<FleetModelDownloadResponse, ClientError>
Get the model download information for the device’s assigned fleet.
Sourcepub fn ingest_telemetry(
&self,
auth_token: impl AsRef<str>,
events: TelemetryIngestionEvents,
) -> Result<(), ClientError>
pub fn ingest_telemetry( &self, auth_token: impl AsRef<str>, events: TelemetryIngestionEvents, ) -> Result<(), ClientError>
Ingest telemetry events for a fleet device.